@@ -415,316 +415,316 @@ primary_habitat <- function() {
 
 municipality <- function() {
 
-  regions <- c(
-    ML.351 = "Keski-Suomi",
-    ML.352 = "Etel\u00e4-Pohjanmaa",
-    ML.353 = "Pirkanmaa",
-    ML.354 = "Etel\u00e4-Pohjanmaa",
-    ML.355 = "Pohjois-Pohjanmaa",
-    ML.356 = "Etel\u00e4-Pohjanmaa",
-    ML.357 = "P\u00e4ij\u00e4t-H\u00e4me",
-    ML.358 = "Uusimaa",
-    ML.359 = "Varsinais-Suomi",
+ regions <- c(
+    ML.351 = "Ahvenanmaa",
+    ML.352 = "Uusimaa",
+    ML.353 = "Ahvenanmaa",
+    ML.354 = "Ahvenanmaa",
+    ML.355 = "Ahvenanmaa",
+    ML.356 = "Ahvenanmaa",
+    ML.357 = "Ahvenanmaa",
+    ML.358 = "Ahvenanmaa",
+    ML.359 = "Ahvenanmaa",
     ML.360 = "Ahvenanmaa",
     ML.361 = "Ahvenanmaa",
-    ML.362 = "Etel\u00e4-Savo",
-    ML.363 = "Lappi",
+    ML.362 = "Uusimaa",
+    ML.363 = "Uusimaa",
     ML.364 = "Uusimaa",
-    ML.365 = "Satakunta",
-    ML.366 = "Satakunta",
-    ML.367 = "Etel\u00e4-Pohjanmaa",
+    ML.365 = "Uusimaa",
+    ML.366 = "Uusimaa",
+    ML.367 = "Uusimaa",
     ML.368 = "Ahvenanmaa",
     ML.369 = "Ahvenanmaa",
-    ML.370 = "Kanta-H\u00e4me",
-    ML.371 = "Ahvenanmaa",
-    ML.372 = "Pohjois-Pohjanmaa",
-    ML.373 = "Pohjois-Pohjanmaa",
-    ML.374 = "Pohjois-Pohjanmaa",
-    ML.375 = "Keski-Pohjanmaa",
-    ML.376 = "Pirkanmaa",
-    ML.377 = "Kanta-H\u00e4me",
-    ML.378 = "Kymenlaakso",
-    ML.379 = "Ahvenanmaa",
-    ML.380 = "Keski-Suomi",
-    ML.381 = "Uusimaa",
-    ML.382 = "Satakunta",
-    ML.383 = "P\u00e4ij\u00e4t-H\u00e4me",
-    ML.384 = "Kanta-H\u00e4me",
-    ML.385 = "Kanta-H\u00e4me",
-    ML.386 = "Pohjois-Karjala",
-    ML.387 = "P\u00e4ij\u00e4t-H\u00e4me",
-    ML.388 = "Uusimaa",
-    ML.389 = "Etel\u00e4-Savo",
-    ML.390 = "P\u00e4ij\u00e4t-H\u00e4me",
-    ML.391 = "Satakunta",
-    ML.392 = "Kanta-H\u00e4me",
-    ML.393 = "Kainuu",
-    ML.394 = "Uusimaa",
-    ML.396 = "Pohjois-Pohjanmaa",
-    ML.397 = "Pohjois-Savo",
-    ML.398 = "P\u00e4ij\u00e4t-H\u00e4me",
-    ML.399 = "Pirkanmaa",
-    ML.400 = "Etel\u00e4-Pohjanmaa",
-    ML.401 = "Pohjois-Karjala",
-    ML.402 = "Etel\u00e4-Karjala",
-    ML.403 = "Lappi",
-    ML.404 = "Uusimaa",
-    ML.405 = "Etel\u00e4-Pohjanmaa",
-    ML.406 = "Etel\u00e4-Pohjanmaa",
-    ML.407 = "Satakunta",
-    ML.408 = "Keski-Suomi",
-    ML.409 = "Kanta-H\u00e4me",
+    ML.370 = "Uusimaa",
+    ML.371 = "Uusimaa",
+    ML.372 = "Uusimaa",
+    ML.373 = "Varsinais-Suomi",
+    ML.374 = "Ahvenanmaa",
+    ML.375 = "Uusimaa",
+    ML.376 = "Kanta-H\u00e4me",
+    ML.377 = "P\u00e4ij\u00e4t-H\u00e4me",
+    ML.378 = "Kanta-H\u00e4me",
+    ML.379 = "P\u00e4ij\u00e4t-H\u00e4me",
+    ML.380 = "Kanta-H\u00e4me",
+    ML.381 = "P\u00e4ij\u00e4t-H\u00e4me",
+    ML.382 = "Uusimaa",
+    ML.383 = "Uusimaa",
+    ML.384 = "Uusimaa",
+    ML.385 = "Uusimaa",
+    ML.386 = "Varsinais-Suomi",
+    ML.387 = "Varsinais-Suomi",
+    ML.388 = "P\u00e4ij\u00e4t-H\u00e4me",
+    ML.389 = "Uusimaa",
+    ML.390 = "Uusimaa",
+    ML.391 = "Varsinais-Suomi",
+    ML.392 = "Uusimaa",
+    ML.393 = "Varsinais-Suomi",
+    ML.394 = "P\u00e4ij\u00e4t-H\u00e4me",
+    ML.396 = "Kymenlaakso",
+    ML.397 = "Uusimaa",
+    ML.398 = "Uusimaa",
+    ML.399 = "Satakunta",
+    ML.400 = "Satakunta",
+    ML.401 = "Varsinais-Suomi",
+    ML.402 = "Varsinais-Suomi",
+    ML.403 = "Uusimaa",
+    ML.404 = "Kymenlaakso",
+    ML.405 = "P\u00e4ij\u00e4t-H\u00e4me",
+    ML.406 = "P\u00e4ij\u00e4t-H\u00e4me",
+    ML.407 = "Keski-Suomi",
+    ML.408 = "P\u00e4ij\u00e4t-H\u00e4me",
+    ML.409 = "Satakunta",
     ML.410 = "Uusimaa",
-    ML.411 = "Pohjois-Karjala",
-    ML.412 = "Kanta-H\u00e4me",
-    ML.413 = "Ahvenanmaa",
-    ML.414 = "Pohjois-Savo",
-    ML.415 = "Keski-Suomi",
-    ML.416 = "Pohjois-Karjala",
-    ML.417 = "Pirkanmaa",
+    ML.411 = "P\u00e4ij\u00e4t-H\u00e4me",
+    ML.412 = "Kymenlaakso",
+    ML.413 = "Etel\u00e4-Savo",
+    ML.414 = "Pohjois-Karjala",
+    ML.415 = "Pirkanmaa",
+    ML.416 = "Kymenlaakso",
+    ML.417 = "P\u00e4ij\u00e4t-H\u00e4me",
     ML.418 = "Etel\u00e4-Savo",
     ML.419 = "Keski-Suomi",
-    ML.420 = "Varsinais-Suomi",
-    ML.421 = "Pohjois-Savo",
-    ML.422 = "Kainuu",
-    ML.423 = "Pohjois-Pohjanmaa",
-    ML.424 = "Pirkanmaa",
+    ML.420 = "Etel\u00e4-Savo",
+    ML.421 = "Etel\u00e4-Savo",
+    ML.422 = "Etel\u00e4-Karjala",
+    ML.423 = "Etel\u00e4-Savo",
+    ML.424 = "Etel\u00e4-Savo",
     ML.425 = "Etel\u00e4-Savo",
-    ML.426 = "Satakunta",
-    ML.427 = "Keski-Suomi",
-    ML.428 = "Keski-Pohjanmaa",
-    ML.429 = "Etel\u00e4-Pohjanmaa",
-    ML.430 = "Uusimaa",
-    ML.431 = "P\u00e4ij\u00e4t-H\u00e4me",
-    ML.432 = "Pohjois-Pohjanmaa",
+    ML.426 = "Etel\u00e4-Karjala",
+    ML.427 = "Etel\u00e4-Savo",
+    ML.428 = "Etel\u00e4-Karjala",
+    ML.429 = "Satakunta",
+    ML.430 = "Pirkanmaa",
+    ML.431 = "Etel\u00e4-Karjala",
+    ML.432 = "Satakunta",
     ML.433 = "Keski-Suomi",
-    ML.434 = "Satakunta",
-    ML.435 = "Pohjanmaa",
-    ML.436 = "Etel\u00e4-Pohjanmaa",
-    ML.437 = "Etel\u00e4-Pohjanmaa",
-    ML.438 = "Uusimaa",
-    ML.439 = "Keski-Pohjanmaa",
-    ML.440 = "Pohjois-Savo",
-    ML.442 = "Lappi",
-    ML.443 = "Lappi",
-    ML.444 = "Lappi",
-    ML.445 = "Varsinais-Suomi",
-    ML.446 = "Pohjois-Pohjanmaa",
-    ML.447 = "Uusimaa",
-    ML.449 = "Keski-Suomi",
-    ML.450 = "Pirkanmaa",
-    ML.451 = "Keski-Suomi",
-    ML.452 = "Uusimaa",
-    ML.453 = "Pohjois-Karjala",
-    ML.454 = "Lappi",
-    ML.455 = "Pohjois-Savo",
-    ML.456 = "Keski-Suomi",
-    ML.457 = "Ahvenanmaa",
-    ML.458 = "Satakunta",
-    ML.459 = "Keski-Pohjanmaa",
-    ML.460 = "Lappi",
-    ML.461 = "Keski-Suomi",
-    ML.462 = "Pohjois-Karjala",
-    ML.464 = "Pohjanmaa",
-    ML.465 = "Varsinais-Suomi",
-    ML.466 = "Kymenlaakso",
-    ML.467 = "Kymenlaakso",
-    ML.468 = "Pohjanmaa",
-    ML.469 = "Pohjanmaa",
-    ML.470 = "Kainuu",
-    ML.471 = "Pirkanmaa",
-    ML.472 = "Ahvenanmaa",
-    ML.473 = "Pohjois-Savo",
-    ML.474 = "Etel\u00e4-Pohjanmaa",
-    ML.475 = "Etel\u00e4-Pohjanmaa",
-    ML.476 = "Varsinais-Suomi",
-    ML.477 = "Pohjois-Pohjanmaa",
-    ML.478 = "Keski-Suomi",
-    ML.479 = "P\u00e4ij\u00e4t-H\u00e4me",
+    ML.434 = "Keski-Suomi",
+    ML.435 = "Satakunta",
+    ML.436 = "Pohjanmaa",
+    ML.437 = "Kanta-H\u00e4me",
+    ML.438 = "Kanta-H\u00e4me",
+    ML.439 = "Pirkanmaa",
+    ML.440 = "Pirkanmaa",
+    ML.442 = "Pohjois-Savo",
+    ML.443 = "Etel\u00e4-Karjala",
+    ML.444 = "Pohjois-Karjala",
+    ML.445 = "Pohjois-Karjala",
+    ML.446 = "Etel\u00e4-Savo",
+    ML.447 = "Etel\u00e4-Pohjanmaa",
+    ML.449 = "Pohjois-Savo",
+    ML.450 = "Etel\u00e4-Savo",
+    ML.451 = "Etel\u00e4-Karjala",
+    ML.452 = "Pohjois-Karjala",
+    ML.453 = "Pohjois-Savo",
+    ML.454 = "Pohjois-Savo",
+    ML.455 = "Satakunta",
+    ML.456 = "Varsinais-Suomi",
+    ML.457 = "Varsinais-Suomi",
+    ML.458 = "Varsinais-Suomi",
+    ML.459 = "Satakunta",
+    ML.460 = "Varsinais-Suomi",
+    ML.461 = "Varsinais-Suomi",
+    ML.462 = "Varsinais-Suomi",
+    ML.464 = "Satakunta",
+    ML.465 = "Satakunta",
+    ML.466 = "Satakunta",
+    ML.467 = "Satakunta",
+    ML.468 = "Varsinais-Suomi",
+    ML.469 = "Varsinais-Suomi",
+    ML.470 = "Kanta-H\u00e4me",
+    ML.471 = "Etel\u00e4-Karjala",
+    ML.472 = "Varsinais-Suomi",
+    ML.473 = "Varsinais-Suomi",
+    ML.474 = "Etel\u00e4-Karjala",
+    ML.475 = "Varsinais-Suomi",
+    ML.476 = "Kymenlaakso",
+    ML.477 = "Etel\u00e4-Karjala",
+    ML.478 = "Varsinais-Suomi",
+    ML.479 = "Pohjanmaa",
     ML.480 = "Pohjanmaa",
     ML.481 = "Varsinais-Suomi",
-    ML.482 = "Uusimaa",
-    ML.483 = "Pohjois-Savo",
+    ML.482 = "Keski-Pohjanmaa",
+    ML.483 = "Pirkanmaa",
     ML.484 = "Etel\u00e4-Pohjanmaa",
-    ML.485 = "Etel\u00e4-Karjala",
-    ML.486 = "Etel\u00e4-Pohjanmaa",
-    ML.487 = "Keski-Suomi",
-    ML.488 = "Etel\u00e4-Karjala",
-    ML.489 = "Ahvenanmaa",
-    ML.490 = "Pirkanmaa",
-    ML.491 = "Pohjois-Savo",
-    ML.492 = "Keski-Pohjanmaa",
-    ML.493 = "Pohjois-Karjala",
-    ML.494 = "Varsinais-Suomi",
-    ML.495 = "Pohjois-Pohjanmaa",
-    ML.496 = "Pohjois-Karjala",
-    ML.497 = "Uusimaa",
-    ML.498 = "Varsinais-Suomi",
-    ML.499 = "Kanta-H\u00e4me",
-    ML.500 = "Uusimaa",
-    ML.501 = "Keski-Suomi",
-    ML.502 = "Pohjois-Pohjanmaa",
-    ML.503 = "Ahvenanmaa",
-    ML.504 = "Pohjanmaa",
-    ML.505 = "Etel\u00e4-Karjala",
-    ML.506 = "Pohjanmaa",
-    ML.507 = "Ahvenanmaa",
-    ML.508 = "Uusimaa",
-    ML.509 = "Pirkanmaa",
-    ML.510 = "Etel\u00e4-Savo",
-    ML.512 = "Varsinais-Suomi",
-    ML.513 = "Varsinais-Suomi",
-    ML.514 = "Pohjois-Pohjanmaa",
-    ML.515 = "Satakunta",
-    ML.516 = "Kymenlaakso",
-    ML.517 = "Etel\u00e4-Savo",
-    ML.518 = "Pohjois-Pohjanmaa",
-    ML.519 = "Keski-Suomi",
-    ML.520 = "Lappi",
-    ML.521 = "Pohjanmaa",
-    ML.522 = "Keski-Suomi",
-    ML.523 = "Varsinais-Suomi",
-    ML.524 = "Uusimaa",
-    ML.525 = "Varsinais-Suomi",
-    ML.526 = "Satakunta",
-    ML.527 = "Pohjanmaa",
-    ML.528 = "Pohjois-Pohjanmaa",
+    ML.485 = "Etel\u00e4-Pohjanmaa",
+    ML.486 = "Varsinais-Suomi",
+    ML.487 = "Etel\u00e4-Savo",
+    ML.488 = "Etel\u00e4-Savo",
+    ML.489 = "Pohjois-Karjala",
+    ML.490 = "Pohjanmaa",
+    ML.491 = "Pohjanmaa",
+    ML.492 = "Pohjanmaa",
+    ML.493 = "Pohjanmaa",
+    ML.494 = "Keski-Pohjanmaa",
+    ML.495 = "Pohjois-Savo",
+    ML.496 = "Varsinais-Suomi",
+    ML.497 = "Pirkanmaa",
+    ML.498 = "Etel\u00e4-Pohjanmaa",
+    ML.499 = "Pohjanmaa",
+    ML.500 = "Etel\u00e4-Pohjanmaa",
+    ML.501 = "Etel\u00e4-Pohjanmaa",
+    ML.502 = "Keski-Suomi",
+    ML.503 = "Etel\u00e4-Pohjanmaa",
+    ML.504 = "Keski-Suomi",
+    ML.505 = "Keski-Suomi",
+    ML.506 = "Etel\u00e4-Pohjanmaa",
+    ML.507 = "Keski-Suomi",
+    ML.508 = "Keski-Pohjanmaa",
+    ML.509 = "Kanta-H\u00e4me",
+    ML.510 = "Satakunta",
+    ML.512 = "Etel\u00e4-Pohjanmaa",
+    ML.513 = "Pirkanmaa",
+    ML.514 = "Pirkanmaa",
+    ML.515 = "Keski-Suomi",
+    ML.516 = "Keski-Suomi",
+    ML.517 = "Pohjois-Pohjanmaa",
+    ML.518 = "Keski-Suomi",
+    ML.519 = "Pohjanmaa",
+    ML.520 = "Pohjois-Pohjanmaa",
+    ML.521 = "Pirkanmaa",
+    ML.522 = "Etel\u00e4-Pohjanmaa",
+    ML.523 = "Pohjanmaa",
+    ML.524 = "Pohjanmaa",
+    ML.525 = "Pirkanmaa",
+    ML.526 = "Keski-Pohjanmaa",
+    ML.527 = "Keski-Suomi",
+    ML.528 = "Pirkanmaa",
     ML.529 = "Pirkanmaa",
-    ML.530 = "Varsinais-Suomi",
-    ML.531 = "Pohjois-Karjala",
-    ML.532 = "Uusimaa",
-    ML.533 = "P\u00e4ij\u00e4t-H\u00e4me",
-    ML.534 = "Varsinais-Suomi",
-    ML.536 = "Pirkanmaa",
-    ML.537 = "Pohjois-Pohjanmaa",
-    ML.538 = "Pohjois-Pohjanmaa",
-    ML.539 = "Pohjois-Karjala",
-    ML.541 = "P\u00e4ij\u00e4t-H\u00e4me",
-    ML.542 = "Varsinais-Suomi",
-    ML.543 = "Pirkanmaa",
-    ML.544 = "Kainuu",
-    ML.545 = "Varsinais-Suomi",
-    ML.546 = "Etel\u00e4-Karjala",
-    ML.547 = "Pirkanmaa",
-    ML.548 = "Pohjanmaa",
-    ML.549 = "Lappi",
-    ML.550 = "Lappi",
-    ML.551 = "Keski-Pohjanmaa",
-    ML.552 = "Etel\u00e4-Savo",
-    ML.553 = "Keski-Suomi",
-    ML.554 = "Etel\u00e4-Savo",
-    ML.555 = "Pohjois-Savo",
-    ML.556 = "Pohjanmaa",
-    ML.557 = "Keski-Suomi",
-    ML.558 = "Pirkanmaa",
-    ML.559 = "Pohjois-Karjala",
-    ML.560 = "Satakunta",
-    ML.561 = "Satakunta",
-    ML.562 = "Uusimaa",
-    ML.563 = "Uusimaa",
-    ML.564 = "Lappi",
-    ML.565 = "Varsinais-Suomi",
-    ML.566 = "Pohjois-Pohjanmaa",
-    ML.567 = "Uusimaa",
-    ML.568 = "Pirkanmaa",
-    ML.569 = "Kainuu",
-    ML.570 = "Etel\u00e4-Savo",
+    ML.530 = "Keski-Suomi",
+    ML.531 = "Keski-Suomi",
+    ML.532 = "Keski-Suomi",
+    ML.533 = "Varsinais-Suomi",
+    ML.534 = "Keski-Suomi",
+    ML.536 = "Keski-Suomi",
+    ML.537 = "Kanta-H\u00e4me",
+    ML.538 = "Keski-Suomi",
+    ML.539 = "Keski-Suomi",
+    ML.541 = "Pirkanmaa",
+    ML.542 = "Etel\u00e4-Pohjanmaa",
+    ML.543 = "Etel\u00e4-Pohjanmaa",
+    ML.544 = "Kanta-H\u00e4me",
+    ML.545 = "Etel\u00e4-Pohjanmaa",
+    ML.546 = "Keski-Suomi",
+    ML.547 = "Varsinais-Suomi",
+    ML.548 = "Pohjois-Savo",
+    ML.549 = "Keski-Suomi",
+    ML.550 = "Keski-Suomi",
+    ML.551 = "Etel\u00e4-Pohjanmaa",
+    ML.552 = "Pirkanmaa",
+    ML.553 = "Pohjois-Savo",
+    ML.554 = "Pirkanmaa",
+    ML.555 = "Pirkanmaa",
+    ML.556 = "Etel\u00e4-Pohjanmaa",
+    ML.557 = "Etel\u00e4-Pohjanmaa",
+    ML.558 = "Pohjois-Savo",
+    ML.559 = "Etel\u00e4-Pohjanmaa",
+    ML.560 = "Keski-Pohjanmaa",
+    ML.561 = "Pirkanmaa",
+    ML.562 = "Pirkanmaa",
+    ML.563 = "Satakunta",
+    ML.564 = "Keski-Pohjanmaa",
+    ML.565 = "Keski-Pohjanmaa",
+    ML.566 = "Keski-Pohjanmaa",
+    ML.567 = "Pohjois-Savo",
+    ML.568 = "Kainuu",
+    ML.569 = "Pohjois-Savo",
+    ML.570 = "Pohjois-Savo",
     ML.572 = "Pohjois-Pohjanmaa",
-    ML.573 = "Pohjois-Pohjanmaa",
-    ML.574 = "Pohjois-Pohjanmaa",
-    ML.575 = "Varsinais-Suomi",
-    ML.576 = "Kymenlaakso",
-    ML.577 = "Pohjois-Pohjanmaa",
+    ML.573 = "Pohjois-Savo",
+    ML.574 = "Pohjois-Savo",
+    ML.575 = "Pohjois-Savo",
+    ML.576 = "Pohjois-Savo",
+    ML.577 = "Pirkanmaa",
     ML.578 = "Pohjois-Karjala",
-    ML.579 = "Uusimaa",
-    ML.580 = "Varsinais-Suomi",
-    ML.582 = "Etel\u00e4-Savo",
-    ML.584 = "Lappi",
-    ML.585 = "Satakunta",
-    ML.586 = "Pohjois-Savo",
-    ML.587 = "Pohjois-Savo",
-    ML.588 = "Etel\u00e4-Karjala",
-    ML.589 = "Pohjois-Pohjanmaa",
-    ML.590 = "Kanta-H\u00e4me",
-    ML.591 = "Kainuu",
-    ML.592 = "Lappi",
-    ML.593 = "Etel\u00e4-Karjala",
-    ML.594 = "Pirkanmaa",
-    ML.595 = "Varsinais-Suomi",
-    ML.596 = "Keski-Suomi",
-    ML.597 = "Satakunta",
-    ML.598 = "Lappi",
-    ML.599 = "Varsinais-Suomi",
-    ML.600 = "Ahvenanmaa",
-    ML.601 = "Pirkanmaa",
-    ML.602 = "Varsinais-Suomi",
-    ML.603 = "Etel\u00e4-Karjala",
-    ML.604 = "Etel\u00e4-Savo",
-    ML.605 = "Lappi",
-    ML.606 = "Etel\u00e4-Pohjanmaa",
-    ML.607 = "Pohjois-Pohjanmaa",
-    ML.608 = "Satakunta",
-    ML.609 = "Pohjois-Pohjanmaa",
+    ML.579 = "Pirkanmaa",
+    ML.580 = "Pohjois-Karjala",
+    ML.582 = "Pohjois-Karjala",
+    ML.584 = "Pohjois-Karjala",
+    ML.585 = "Pohjois-Savo",
+    ML.586 = "Pohjois-Pohjanmaa",
+    ML.587 = "Pohjois-Pohjanmaa",
+    ML.588 = "Pohjois-Pohjanmaa",
+    ML.589 = "Kanta-H\u00e4me",
+    ML.590 = "Pohjois-Karjala",
+    ML.591 = "Pohjois-Pohjanmaa",
+    ML.592 = "Kainuu",
+    ML.593 = "Pohjois-Pohjanmaa",
+    ML.594 = "Pohjois-Pohjanmaa",
+    ML.595 = "Pohjois-Pohjanmaa",
+    ML.596 = "Kainuu",
+    ML.597 = "Pohjois-Pohjanmaa",
+    ML.598 = "Pohjois-Pohjanmaa",
+    ML.599 = "Pohjois-Savo",
+    ML.600 = "Lappi",
+    ML.601 = "Pohjois-Pohjanmaa",
+    ML.602 = "Pohjois-Pohjanmaa",
+    ML.603 = "Lappi",
+    ML.604 = "Pohjois-Pohjanmaa",
+    ML.605 = "Kainuu",
+    ML.606 = "Pohjois-Pohjanmaa",
+    ML.607 = "Kainuu",
+    ML.608 = "Pohjois-Pohjanmaa",
+    ML.609 = "Kainuu",
     ML.610 = "Pohjois-Pohjanmaa",
-    ML.611 = "Pohjois-Savo",
-    ML.612 = "Lappi",
-    ML.613 = "Uusimaa",
-    ML.614 = "Uusimaa",
+    ML.611 = "Pohjois-Pohjanmaa",
+    ML.612 = "Pohjois-Karjala",
+    ML.613 = "Kainuu",
+    ML.614 = "Kainuu",
     ML.615 = "Lappi",
-    ML.616 = "Etel\u00e4-Pohjanmaa",
-    ML.617 = "Varsinais-Suomi",
-    ML.618 = "Pohjois-Savo",
-    ML.619 = "Kainuu",
-    ML.620 = "Ahvenanmaa",
-    ML.621 = "Etel\u00e4-Savo",
-    ML.622 = "Ahvenanmaa",
-    ML.623 = "Kainuu",
-    ML.624 = "Pohjois-Savo",
-    ML.625 = "P\u00e4ij\u00e4t-H\u00e4me",
-    ML.626 = "Etel\u00e4-Karjala",
-    ML.627 = "Pohjois-Pohjanmaa",
-    ML.628 = "Varsinais-Suomi",
-    ML.629 = "Kanta-H\u00e4me",
-    ML.630 = "Pirkanmaa",
-    ML.631 = "Pohjois-Savo",
+    ML.616 = "Pohjois-Pohjanmaa",
+    ML.617 = "Lappi",
+    ML.618 = "Lappi",
+    ML.619 = "Lappi",
+    ML.620 = "Lappi",
+    ML.621 = "Lappi",
+    ML.622 = "Lappi",
+    ML.623 = "Lappi",
+    ML.624 = "Lappi",
+    ML.625 = "Lappi",
+    ML.626 = "Lappi",
+    ML.627 = "Lappi",
+    ML.628 = "Lappi",
+    ML.629 = "Lappi",
+    ML.630 = "Lappi",
+    ML.631 = "Lappi",
     ML.632 = "Lappi",
-    ML.633 = "Etel\u00e4-Pohjanmaa",
-    ML.634 = "Pohjois-Karjala",
-    ML.635 = "Keski-Pohjanmaa",
-    ML.636 = "Keski-Suomi",
-    ML.637 = "Lappi",
-    ML.638 = "Varsinais-Suomi",
-    ML.639 = "Pohjois-Savo",
-    ML.640 = "Uusimaa",
-    ML.641 = "Pohjois-Pohjanmaa",
-    ML.642 = "Satakunta",
-    ML.643 = "Pirkanmaa",
+    ML.633 = "Lappi",
+    ML.634 = "Lappi",
+    ML.635 = "Kanta-H\u00e4me",
+    ML.636 = "Pohjois-Karjala",
+    ML.637 = "Pohjois-Karjala",
+    ML.638 = "Pohjois-Pohjanmaa",
+    ML.639 = "Pohjois-Pohjanmaa",
+    ML.640 = "Pohjois-Pohjanmaa",
+    ML.641 = "Satakunta",
+    ML.642 = "Pohjois-Pohjanmaa",
+    ML.643 = "Uusimaa",
     ML.644 = "Pohjois-Pohjanmaa",
-    ML.645 = "Lappi",
-    ML.647 = "Keski-Suomi",
-    ML.648 = "Pohjanmaa",
-    ML.649 = "Varsinais-Suomi",
+    ML.645 = "Pohjois-Pohjanmaa",
+    ML.647 = "Varsinais-Suomi",
+    ML.648 = "Uusimaa",
+    ML.649 = "Satakunta",
     ML.650 = "Pohjois-Pohjanmaa",
-    ML.651 = "Pohjanmaa",
-    ML.652 = "Pirkanmaa",
-    ML.653 = "Uusimaa",
-    ML.654 = "Ahvenanmaa",
+    ML.651 = "Ahvenanmaa",
+    ML.652 = "Pohjanmaa",
+    ML.653 = "Etel\u00e4-Pohjanmaa",
+    ML.654 = "Pohjanmaa",
     ML.655 = "Pohjois-Savo",
-    ML.656 = "Varsinais-Suomi",
-    ML.657 = "Pohjois-Savo",
-    ML.658 = "Pirkanmaa",
-    ML.659 = "Keski-Pohjanmaa",
-    ML.660 = "Pohjois-Savo",
-    ML.661 = "Uusimaa",
-    ML.662 = "Keski-Suomi",
-    ML.663 = "Etel\u00e4-Pohjanmaa",
-    ML.664 = "Kymenlaakso",
-    ML.665 = "Pirkanmaa",
-    ML.666 = "Pohjanmaa",
-    ML.667 = "Lappi",
-    ML.668 = "Pohjois-Pohjanmaa",
-    ML.669 = "Pirkanmaa",
-    ML.670 = "Kanta-H\u00e4me"
+    ML.656 = "Ahvenanmaa",
+    ML.657 = "Pohjois-Pohjanmaa",
+    ML.658 = "Pohjois-Pohjanmaa",
+    ML.659 = "Pohjois-Savo",
+    ML.660 = "Uusimaa",
+    ML.661 = "Kymenlaakso",
+    ML.662 = "Ahvenanmaa",
+    ML.663 = "Pirkanmaa",
+    ML.664 = "Varsinais-Suomi",
+    ML.665 = "Varsinais-Suomi",
+    ML.666 = "Pirkanmaa",
+    ML.667 = "Uusimaa",
+    ML.668 = "Pirkanmaa",
+    ML.669 = "Pohjois-Pohjanmaa",
+    ML.670 = "Pohjanmaa"
   )
 
   municipalities <- get_areas("municipality")
@@ -1071,13 +1071,13 @@ record_quality <- function() {
 
 record_reliability <- function() {
 
-  r <- c("RELIABLE", "NEUTRAL", "UNRELIABLE")
+  r <- c("RELIABLE", "UNDEFINED", "UNRELIABLE")
 
   reliability <- list(
-    code = c("reliable", "undefined", "unreliable"),
-    name_en = c("Reliable", "Undefined", "Unreliable"),
+    code = c("reliable", "unassessed", "Unreliable"),
+    name_en = c("Reliable", "Unassessed", "Unreliable"),
     name_fi = c("Luotettava", "Neutraali", "Ep\u00e4luotettava"),
-    name_sv = c("P\u00e5litlig", "Neutral", "Opu00e5litliga")
+    name_sv = c("P\u00e5litlig", "Neutral", "Op\u00e5litliga")
   )
 
   reliability <- structure(reliability, row.names = r, class = "data.frame")
